@@ -90,6 +90,7 @@
 #define GF_XATTR_GET_REAL_FILENAME_KEY "glusterfs.get_real_filename:"
 #define GF_XATTR_USER_PATHINFO_KEY   "glusterfs.pathinfo"
 #define GF_INTERNAL_IGNORE_DEEM_STATFS "ignore-deem-statfs"
+#define GF_XATTR_IOSTATS_DUMP_KEY "trusted.io-stats-dump"
 
 #define GF_READDIR_SKIP_DIRS       "readdir-filter-directories"
 #define GF_MDC_LOADED_KEY_NAMES     "glusterfs.mdc.loaded.key.names"
@@ -169,6 +170,9 @@
 #define VIRTUAL_QUOTA_XATTR_CLEANUP_KEY "glusterfs.quota-xattr-cleanup"
 #define QUOTA_READ_ONLY_KEY "trusted.glusterfs.quota.read-only"
 
+/* afr related */
+#define AFR_XATTR_PREFIX "trusted.afr"
+
 /* Index xlator related */
 #define GF_XATTROP_INDEX_GFID "glusterfs.xattrop_index_gfid"
 #define GF_XATTROP_ENTRY_CHANGES_GFID "glusterfs.xattrop_entry_changes_gfid"
@@ -177,6 +181,8 @@
 #define GF_XATTROP_DIRTY_COUNT "glusterfs.xattrop_dirty_count"
 #define GF_XATTROP_ENTRY_IN_KEY "glusterfs.xattrop-entry-create"
 #define GF_XATTROP_ENTRY_OUT_KEY "glusterfs.xattrop-entry-delete"
+#define GF_INDEX_IA_TYPE_GET_REQ "glusterfs.index-ia-type-get-req"
+#define GF_INDEX_IA_TYPE_GET_RSP "glusterfs.index-ia-type-get-rsp"
 
 #define GF_HEAL_INFO "glusterfs.heal-info"
 #define GF_AFR_HEAL_SBRAIN "glusterfs.heal-sbrain"
@@ -343,7 +349,6 @@ struct _cmd_args {
         int              acl;
         int              selinux;
         int              capability;
-        char            *oom_score_adj;
         int              enable_ino32;
         int              worm;
         int              mac_compat;
@@ -389,6 +394,11 @@ struct _cmd_args {
 
         /* Should management connections use SSL? */
         int             secure_mgmt;
+
+        /* Linux-only OOM killer adjustment */
+#ifdef GF_LINUX_HOST_OS
+        char            *oom_score_adj;
+#endif
 };
 typedef struct _cmd_args cmd_args_t;
 
@@ -552,7 +562,7 @@ int glusterfs_graph_destroy (glusterfs_graph_t *graph);
 int glusterfs_get_leaf_count (glusterfs_graph_t *graph);
 int glusterfs_graph_activate (glusterfs_graph_t *graph, glusterfs_ctx_t *ctx);
 glusterfs_graph_t *glusterfs_graph_construct (FILE *fp);
-glusterfs_graph_t *glusterfs_graph_new ();
+glusterfs_graph_t *glusterfs_graph_new (void);
 int glusterfs_graph_reconfigure (glusterfs_graph_t *oldgraph,
                                   glusterfs_graph_t *newgraph);
 
